import {Component, OnDestroy, OnInit} from '@angular/core';
import {LecturerDataService} from 'src/app/services/lecturer-data.service';
import {LecturerInfoService} from 'src/app/services/lecturer-info.service';
import {QuestionDao} from 'src/app/dao/question.dao';
import {AnswerSetDao} from 'src/app/dao/answer-set.dao';
import {GridOptions} from 'ag-grid-community';
import {ViewResponsesButtonComponent} from 'src/app/GridComponents/ViewResponsesButton/view-responses-button.component';
import {Subject} from 'rxjs';
import {Router} from '@angular/router';

@Component({
  selector: 'app-lecturer-submissionsview',
  templateUrl: './lecturer-submissions-view.component.html',
  styleUrls: ['./lecturer-submissions-view.component.css']
})
export class LecturerSubmissionsViewComponent implements OnInit, OnDestroy {

  public responseEventSubject: Subject<AnswerSetDao> = new Subject();
  public lecturerId;
  public classCode;
  public paper;
  public questions: QuestionDao[];
  public answers: AnswerSetDao[];
  public rowData: any;
  public gridOptions: GridOptions;
  public columnDefs = [
    {headerName: 'Username', valueGetter: params =>  params.data.answerSets[0].username, sortable: true, lockPosition: true},
    {headerName: 'Submission Date', valueGetter: params => params.data.answerSets[0].submissionDate, sortable: true, lockPosition: true},
    {headerName: 'View', field: '', cellRendererFramework: ViewResponsesButtonComponent, lockPosition: true},
  ];

  constructor(private lecturerDataService: LecturerDataService,
              private lecturerInfoService: LecturerInfoService,
              private router: Router) {
  }

  ngOnInit(): void {
    this.questions = [];
    this.answers = [];
    this.lecturerId = sessionStorage.getItem('username');
    this.classCode = this.lecturerDataService.classCode;
    this.paper = this.lecturerDataService.currentPaper;
    this.rowData = this.lecturerInfoService.getPaperAnswers(this.paper.paperId);
    this.gridOptions = {
      context: {componentParent: this}
    };
    this.getPaperQuestions();
  }

  ngOnDestroy(): void {
    this.questions = [];
    this.answers = [];
  }

  public goToResponse(set: AnswerSetDao): void {
    this.lecturerDataService.currentAnswerSet = set;
    this.lecturerDataService.currentQuestions = this.questions;
    this.responseEventSubject.next(set);
  }

  private getPaperQuestions(): void {
    this.lecturerInfoService.getPaperQuestions(this.paper.paperId).subscribe((data: QuestionDao[]) => {
      data.forEach(e => this.questions.push(e));
    });
  }

  public back() {
    this.router.navigate(['/paper-view']);
    this.ngOnDestroy();
  }

}
